@@ -266,9 +266,14 @@ class FPLAnalytics:
         return combPlayerdetails
     
     def findPlayer(self, pattern):
-        pattern = "|".join(pattern.split(" "))
-        result = self.getPlayerSummary()
-        result = result[result['web_name'].str.contains(pattern, flags=re.IGNORECASE, regex=True)]
+        players = [p.strip() for p in pattern.split(' ')]
+        stats = self.getPlayerSummary()
+        result = pd.DataFrame()
+        for p in players:
+            df = stats[stats['web_name'].str.match(p, flags=re.IGNORECASE)]
+            if df.shape[0] == 0:
+                df = stats[stats['web_name'].str.contains(p, flags=re.IGNORECASE, regex=True)]
+            result = pd.concat([result, df])
         return result
 
     def getPlayerUnderStats(self):
@@ -388,7 +393,9 @@ class FPLAnalytics:
 
             angles = [n / float(N) * 2 * pi for n in range(N)]
             angles += angles[:1]
-            ax = plt.subplot(111, polar=True)
+            #ax = plt.subplot(111, polar=True)
+            fig = plt.figure()
+            ax = fig.add_subplot(111, polar=True)
             ax.set_theta_offset(pi / 2)
             ax.set_theta_direction(-1)
             plt.xticks(angles[:-1], features)
@@ -405,6 +412,8 @@ class FPLAnalytics:
 
             plt.legend(loc='upper right', bbox_to_anchor=(0.1, 0.1))
             if filename:
-                plt.savefig(filename + '.png')
+                fig.savefig(filename + '.png')
+                plt.close(fig)
         
         return players
+
